yakumo.nova.v2.aggregate.Manager

Package yakumo :: Package nova :: Package v2 :: Module aggregate :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for aggregates in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for aggregates in Compute API v2

Instance Methods | [hide private]
_json2attr(self, json_params) | source code
yakumo.nova.v2.aggregate.Resource |
create(self, name=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`, metadata=`'``__UNDEF__``'`) Create a host aggregate | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``aggregate``'``
| _json_resources_key = ``'``aggregates``'``
| _url_resource_path = ``'``/os-aggregates``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### _json2attr(self, json_params) | source code
Overrides: base.Manager._json2attr

### create(self, name=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`, metadata=`'``__UNDEF__``'`) | source code
Create a host aggregate Parameters: `name` (str) - name of the host aggregate `availability_zone` (str) - name of availability zone `metadata` (dict) - Metadata Returns: yakumo.nova.v2.aggregate.Resource Created host aggregate Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('hosts', '
      hosts', mapper.Noop), ('availability_zone', 'availability_zone', mappe
      r.Noop), ('metadata', 'metadata', mapper.Noop), ('created_at', 'create
      d_at', mapper.DateTime), ('updated_at', 'updated_at', mapper.DateTime)
      , ('deleted_at', 'deleted_at', mapper.DateTime), ('is_deleted', 'delet
      ed', mapper.Noop),]